==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Circle/Circle2TR/ts/Circle2TR_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>Circle2TR</name>
    <message>
        <location filename="../Circle2TR.js" line="+76"/>
        <source>First line, arc or circle</source>
        <translation>Első vonal, ív vagy kör</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Second line, arc or circle</source>
        <translation>Második vonal, ív vagy kör</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Choose solution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+97"/>
        <location line="+94"/>
        <source>No solution</source>
        <translation>Nincs megoldás</translation>
    </message>
    <message>
        <location line="-44"/>
        <source>Invalid radius</source>
        <translation>Érvénytelen sugár</translation>
    </message>
    <message>
        <location filename="../Circle2TR.ui" line="+17"/>
        <source>Radius:</source>
        <translation>Sugár:</translation>
    </message>
    <message>
        <location filename="../Circle2TRInit.js" line="+2"/>
        <source>2 &amp;Tangents and Radius</source>
        <translation>2 érintő és sugár</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Draw circle tangential to two entities with given radius</source>
        <translation>Két elemet érintő kör szerkesztése adott sugárral</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Circle/Circle2TR/ts/Circle2TR_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>Circle2TR</name>
    <message>
        <location filename="../Circle2TR.js" line="+77"/>
        <source>First line, arc or circle</source>
        <translation>Első vonal, ív vagy kör</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Second line, arc or circle</source>
        <translation>Második vonal, ív vagy kör</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Choose solution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+99"/>
        <source>No solution</source>
        <translation>Nincs megoldás</translation>
    </message>
    <message>
        <source>Invalid radius</source>
        <translation type="vanished">Érvénytelen sugár</translation>
    </message>
    <message>
        <location filename="../Circle2TR.ui" line="+17"/>
        <source>Radius:</source>
        <translation>Sugár:</translation>
    </message>
    <message>
        <location filename="../Circle2TRInit.js" line="+2"/>
        <source>2 &amp;Tangents and Radius</source>
        <translation>2 érintő és sugár</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Draw circle tangential to two entities with given radius</source>
        <translation>Két elemet érintő kör szerkesztése adott sugárral</translation>
    </message>
</context>
</TS>
